import { blueGlow } from '../filters/blue-glow';
import { goovey } from '../filters/goovey';
import { redGlow } from '../filters/red-glow';
import { scribble } from '../filters/scribble';
import { tv_noise } from '../filters/tv_noise';
import { paper } from '../filters/paper';
import { blur_filter } from '../filters/blur_filter';

import { drugsPattern } from '../patterns/drugs.pattern';

import { army_defence } from '../defs/army_defence/army_defence';
import { boom } from '../defs/boom/boom';
import { flagAnimated } from '../defs/flag';
import { small_glare } from '../defs/small_glare/small_glare';
import { glare } from '../defs/glare/glare';
import { cat } from '../defs/cat/cat';
import { rent } from '../defs/rent/rent';
import { winner } from '../defs/winner/winner';
import { lost } from '../defs/lost/lost';
import { player_lock } from '../defs/player_lock/player_lock';
import { note_1, note_2, note_3, note_4 } from '../defs/music_notes';
import { enemyFlagSvgStyles, flagStarsStyles, myFlagSvgStyles } from '../western-world.utils.constants';
import { black_background } from '../defs/black-background';
import { bird } from '../defs/bird/bird';
import { clouds_29 } from '../defs/clouds_29/clouds_29';
import { clouds_49 } from '../defs/clouds_49/clouds_49';
import { clouds_63 } from '../defs/clouds_63/clouds_63';
import { clouds_78 } from '../defs/clouds_78/clouds_78';
import { item_48 } from '../defs/item_48/item_48';
import { buble } from '../defs/buble/buble';
import { heart } from '../defs/heart';
import { grass } from '../defs/grass';
import { triple_step } from '../defs/triple_step/triple_step';
import { buy } from '../defs/buy/buy';
import { banknotes } from '../defs/banknotes/banknotes';
import { dollar } from '../defs/dollar';
import { envelope } from '../defs/envelope';
import { bribery_of_police_defence } from '../defs/bribery_of_police_defence/bribery_of_police_defence';
import { no_taxes_defence } from '../defs/no_taxes_defence/no_taxes_defence';
import { mouse } from '../defs/mouse/mouse';
import { museum } from '../defs/museum';
import { coin } from '../defs/coin';
import { small_coin } from '../defs/coin-small';
import { liguid_in_circle } from '../defs/liguid_in_circle';
import { add_money } from '../defs/add_money/add_money';
import { remove_money } from '../defs/remove_money/remove_money';
import { white_smoke } from '../defs/white_smoke';
import { hand_with_coin } from '../defs/hand_with_coin';
import { add_deposit } from '../defs/add_deposit/add_deposit';
import { jar_background, jar_bottom, jar_money, jar_top } from '../defs/jar';
import { remove_deposit } from '../defs/remove_deposit/remove_deposit';
import { coin_2 } from '../defs/coin_2';
import { hand_simple } from '../defs/hand';
import { army_logo } from '../defs/army_logo';
import { buy_army } from '../defs/buy_army/buy_army';
import { buy_bribery_of_police } from '../defs/buy_bribery_of_police/buy_bribery_of_police';
import { remove_credit } from '../defs/remove_credit/remove_credit';
import { wing } from '../defs/wing';
import { money_with_wings } from '../defs/money_with_wings/money_with_wings';
import { remove_money_simple } from '../defs/remove_money_simple/remove_money_simple';
import { drug } from '../defs/drug';
import { drug_buble } from '../defs/drug_buble/drug_buble';
import { add_drugs } from '../defs/add_drugs/add_drugs';
import { sell } from '../defs/sell/sell';
import { confetti } from '../defs/confetti/confetti';
import { add_star } from '../defs/add_star/add_star';
import { star } from '../defs/star';
import { simpleglitchfilter } from '../filters/simple-glitch-filter';
import { elephant_pattern } from '../patterns/elephant.pattern';
import { fish } from '../defs/fish/fish';
import { bank } from '../defs/bank';

export const others = {
  // backgrounds;
  'background-top-elements': {
    svg: require('./backgrounds/background-top-elements.svg'),
  },
  background: {
    svg: require('./backgrounds/background.svg'),
  },
  'colony-arrows': {
    svg: require('./backgrounds/colony-arrows.svg'),
  },
  desert: {
    svg: require('./backgrounds/desert.svg'),
  },
  forest: {
    svg: require('./backgrounds/forest.svg'),
    css: require('!!css-loader!sass-loader!../scss/backgrounds/forest.scss').default,
  },
  progress: {
    svg: require('./backgrounds/progress.svg'),
    css: require('!!css-loader!sass-loader!../scss/backgrounds/progress.scss').default,
  },
  start: {
    svg: require('./backgrounds/start.svg'),
    css: require('!!css-loader!sass-loader!../scss/backgrounds/start.scss').default,
  },
  slippery_path_snake: {
    svg: require('./backgrounds/slippery-path-snake.svg'),
  },

  // others;
  circle_is_done: {
    svg: require('./others/circle_is_done.svg'),
    css: require('!!css-loader!sass-loader!../scss/others/circle_is_done.scss').default,
  },
  star: {
    svg: require('./others/star.svg'),
  },
  winner: {
    svg: require('./others/winner.svg'),
    css: require('!!css-loader!sass-loader!../scss/others/winner.scss').default,
    defs: [{ name: 'winner', value: winner, type: 'symbol' }],
  },
  lost: {
    svg: require('./others/lost.svg'),
    css: require('!!css-loader!sass-loader!../scss/others/lost.scss').default,
    defs: [{ name: 'lost', value: lost, type: 'symbol' }],
  },
  question_marks: {
    svg: require('./others/question_marks.svg'),
    css: require('!!css-loader!sass-loader!../scss/others/question_marks.scss').default,
  },
  confetti: {
    svg: require('./others/confetti.svg'),
    css: '',
    defs: [{ name: 'confetti', value: confetti, type: 'symbol' }],
  },

  // flags
  'my-flag-stars-0': {
    svg: require('./others/flag.svg'),
    css: `${myFlagSvgStyles} ${flagStarsStyles[0]}`,
  },
  'my-flag-stars-1': {
    svg: require('./others/flag.svg'),
    css: `${myFlagSvgStyles} ${flagStarsStyles[1]}`,
  },
  'my-flag-stars-2': {
    svg: require('./others/flag.svg'),
    css: `${myFlagSvgStyles} ${flagStarsStyles[2]}`,
  },
  'my-flag-stars-3': {
    svg: require('./others/flag.svg'),
    css: `${myFlagSvgStyles} ${flagStarsStyles[3]}`,
  },
  'my-flag-stars-4': {
    svg: require('./others/flag.svg'),
    css: `${myFlagSvgStyles} ${flagStarsStyles[4]}`,
  },
  'my-flag-stars-5': {
    svg: require('./others/flag.svg'),
    css: `${myFlagSvgStyles} ${flagStarsStyles[5]}`,
  },
  'enemy-flag-stars-0': {
    svg: require('./others/flag.svg'),
    css: `${enemyFlagSvgStyles} ${flagStarsStyles[0]}`,
  },
  'enemy-flag-stars-1': {
    svg: require('./others/flag.svg'),
    css: `${enemyFlagSvgStyles} ${flagStarsStyles[1]}`,
  },
  'enemy-flag-stars-2': {
    svg: require('./others/flag.svg'),
    css: `${enemyFlagSvgStyles} ${flagStarsStyles[2]}`,
  },
  'enemy-flag-stars-3': {
    svg: require('./others/flag.svg'),
    css: `${enemyFlagSvgStyles} ${flagStarsStyles[3]}`,
  },
  'enemy-flag-stars-4': {
    svg: require('./others/flag.svg'),
    css: `${enemyFlagSvgStyles} ${flagStarsStyles[4]}`,
  },
  'enemy-flag-stars-5': {
    svg: require('./others/flag.svg'),
    css: `${enemyFlagSvgStyles} ${flagStarsStyles[5]}`,
  },
};

export const cells = {
  abcde: {
    svg: require('./cells/abcde.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/abcde.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'tv_noise', value: tv_noise, type: 'filter' },
      { name: 'simpleglitchfilter', value: simpleglitchfilter, type: 'filter' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  accident: {
    svg: require('./cells/accident.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/accident.scss').default,
    defs: [{ name: 'coin', value: coin, type: 'symbol_additional' }],
  },
  ads: {
    svg: require('./cells/ads.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/ads.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  ambulance_2: {
    svg: require('./cells/ambulance_2.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/ambulance_2.scss').default,
    defs: [
      { name: 'redGlow', value: redGlow, type: 'filter' },
      { name: 'blueGlow', value: blueGlow, type: 'filter' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'remove_money_simple', value: remove_money_simple, type: 'symbol' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'cat', value: cat, type: 'symbol_additional' },
    ],
  },
  army: {
    svg: require('./cells/army.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/army.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'banknotes', value: banknotes, type: 'symbol_additional' },
      { name: 'buy_army', value: buy_army, type: 'symbol' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
    ],
  },
  attempt_to_kill_player: {
    svg: require('./cells/attempt_to_kill_player.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/attempt_to_kill_player.scss').default,
  },
  auction_started: {
    svg: require('./cells/auction_started.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/auction_started.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
    ],
  },
  bamper: {
    svg: require('./cells/bamper.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bamper.scss').default,
    defs: [
      { name: 'goovey', value: goovey, type: 'filter' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  banana_plantation: {
    svg: require('./cells/banana_plantation.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/banana_plantation.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  bank: {
    svg: require('./cells/bank.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bank.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_deposit', value: add_deposit, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'jar_background', value: jar_background, type: 'symbol_additional' },
      { name: 'jar_bottom', value: jar_bottom, type: 'symbol_additional' },
      { name: 'jar_money', value: jar_money, type: 'symbol_additional' },
      { name: 'jar_top', value: jar_top, type: 'symbol_additional' },
      { name: 'remove_deposit', value: remove_deposit, type: 'symbol' },
      { name: 'hand_simple', value: hand_simple, type: 'symbol_additional' },
      { name: 'coin_2', value: coin_2, type: 'symbol_additional' },
      { name: 'remove_credit', value: remove_credit, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  bank_27: {
    svg: require('./cells/bank_27.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bank_27.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_deposit', value: add_deposit, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'jar_background', value: jar_background, type: 'symbol_additional' },
      { name: 'jar_bottom', value: jar_bottom, type: 'symbol_additional' },
      { name: 'jar_money', value: jar_money, type: 'symbol_additional' },
      { name: 'jar_top', value: jar_top, type: 'symbol_additional' },
      { name: 'remove_deposit', value: remove_deposit, type: 'symbol' },
      { name: 'hand_simple', value: hand_simple, type: 'symbol_additional' },
      { name: 'coin_2', value: coin_2, type: 'symbol_additional' },
      { name: 'remove_credit', value: remove_credit, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  bank_8: {
    svg: require('./cells/bank_8.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bank_8.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_deposit', value: add_deposit, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'jar_background', value: jar_background, type: 'symbol_additional' },
      { name: 'jar_bottom', value: jar_bottom, type: 'symbol_additional' },
      { name: 'jar_money', value: jar_money, type: 'symbol_additional' },
      { name: 'jar_top', value: jar_top, type: 'symbol_additional' },
      { name: 'remove_deposit', value: remove_deposit, type: 'symbol' },
      { name: 'hand_simple', value: hand_simple, type: 'symbol_additional' },
      { name: 'coin_2', value: coin_2, type: 'symbol_additional' },
      { name: 'remove_credit', value: remove_credit, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  bank_crash: {
    svg: require('./cells/bank_crash.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bank_crash.scss').default,
  },
  bank_jungle: {
    svg: require('./cells/bank_jungle.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bank_jungle.scss').default,
    defs: [
      { name: 'bank', value: bank, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_deposit', value: add_deposit, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'jar_background', value: jar_background, type: 'symbol_additional' },
      { name: 'jar_bottom', value: jar_bottom, type: 'symbol_additional' },
      { name: 'jar_money', value: jar_money, type: 'symbol_additional' },
      { name: 'jar_top', value: jar_top, type: 'symbol_additional' },
      { name: 'remove_deposit', value: remove_deposit, type: 'symbol' },
      { name: 'hand_simple', value: hand_simple, type: 'symbol_additional' },
      { name: 'coin_2', value: coin_2, type: 'symbol_additional' },
      { name: 'remove_credit', value: remove_credit, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  bank_robbery: {
    svg: require('./cells/bank_robbery.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bank_robbery.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  bermuda_triangle: {
    svg: require('./cells/bermuda_triangle.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bermuda_triangle.scss').default,
    defs: [{ name: 'clouds_49', value: clouds_49, type: 'symbol_additional' }],
  },
  bet_on_star_won_40: {
    svg: require('./cells/bet_on_star_won_40.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bet_on_star_won_40.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'winner', value: winner, type: 'symbol' },
      { name: 'note_1', value: note_1, type: 'symbol_additional' },
      { name: 'note_2', value: note_2, type: 'symbol_additional' },
      { name: 'note_3', value: note_3, type: 'symbol_additional' },
      { name: 'note_4', value: note_4, type: 'symbol_additional' },
    ],
  },
  bet_on_star_won_41: {
    svg: require('./cells/bet_on_star_won_41.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bet_on_star_won_41.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'winner', value: winner, type: 'symbol' },
      { name: 'note_1', value: note_1, type: 'symbol_additional' },
      { name: 'note_2', value: note_2, type: 'symbol_additional' },
      { name: 'note_3', value: note_3, type: 'symbol_additional' },
      { name: 'note_4', value: note_4, type: 'symbol_additional' },
    ],
  },
  bought_10_cars: {
    svg: require('./cells/bought_10_cars.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bought_10_cars.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'small_glare', value: small_glare, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  bought_drugs_10_tons: {
    svg: require('./cells/bought_drugs_10_tons.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bought_drugs_10_tons.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'drug', value: drug, type: 'symbol_additional' },
      { name: 'drugsPattern', value: drugsPattern, type: 'pattern' },
      { name: 'drug_buble', value: drug_buble, type: 'symbol_additional' },
      { name: 'blur_filter', value: blur_filter, type: 'filter' },
      { name: 'add_drugs', value: add_drugs, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  bread_plantation: {
    svg: require('./cells/bread_plantation.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bread_plantation.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  bribery_of_police: {
    svg: require('./cells/bribery_of_police.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bribery_of_police.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy_bribery_of_police', value: buy_bribery_of_police, type: 'symbol' },
      { name: 'envelope', value: envelope, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  bribery_of_the_labor_aristocracy: {
    svg: require('./cells/bribery_of_the_labor_aristocracy.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/bribery_of_the_labor_aristocracy.scss').default,
  },
  broadcast: {
    svg: require('./cells/broadcast.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/broadcast.scss').default,
  },
  broiler_digest: {
    svg: require('./cells/broiler_digest.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/broiler_digest.scss').default,
    defs: [
      { name: 'goovey', value: goovey, type: 'filter' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  broken_safe: {
    svg: require('./cells/broken_safe.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/broken_safe.scss').default,
    defs: [
      { name: 'small_coin', value: small_coin, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  buy_barrel_oil: {
    svg: require('./cells/buy_barrel_oil.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/buy_barrel_oil.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  buy_gold: {
    svg: require('./cells/buy_gold.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/buy_gold.scss').default,
    defs: [{ name: 'small_glare', value: small_glare, type: 'symbol_additional' }],
  },
  cafe_bogema: {
    svg: require('./cells/cafe_bogema.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/cafe_bogema.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'cat', value: cat, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  came_back: {
    svg: require('./cells/came_back.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/came_back.scss').default,
    defs: [
      { name: 'small_glare', value: small_glare, type: 'symbol_additional' },
      { name: 'glare', value: glare, type: 'symbol_additional' },
    ],
  },
  casino: {
    svg: require('./cells/casino.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/casino.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'winner', value: winner, type: 'symbol' },
      { name: 'lost', value: lost, type: 'symbol' },
    ],
  },
  coffee: {
    svg: require('./cells/coffee.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/coffee.scss').default,
    defs: [
      { name: 'goovey', value: goovey, type: 'filter' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'liguid_in_circle', value: liguid_in_circle, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  coffee_break: {
    svg: require('./cells/coffee_break.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/coffee_break.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
      { name: 'remove_money_simple', value: remove_money_simple, type: 'symbol' },
    ],
  },
  commodityexchange_15: {
    svg: require('./cells/commodityexchange_15.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/commodityexchange_15.scss').default,
  },
  commodityexchange_26: {
    svg: require('./cells/commodityexchange_26.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/commodityexchange_26.scss').default,
  },
  commodityexchange_33: {
    svg: require('./cells/commodityexchange_33.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/commodityexchange_33.scss').default,
  },
  contribution_to_the_brain: {
    svg: require('./cells/contribution_to_the_brain.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/contribution_to_the_brain.scss').default,
  },
  crack_house: {
    svg: require('./cells/crack_house.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/crack_house.scss').default,
    defs: [
      { name: 'white_smoke', value: white_smoke, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'drug', value: drug, type: 'symbol_additional' },
      { name: 'drug_buble', value: drug_buble, type: 'symbol_additional' },
      { name: 'blur_filter', value: blur_filter, type: 'filter' },
      { name: 'add_drugs', value: add_drugs, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  crisis_of_confidence: {
    svg: require('./cells/crisis_of_confidence.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/crisis_of_confidence.scss').default,
  },
  crocodile: {
    svg: require('./cells/crocodile.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/crocodile.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'army_defence', value: army_defence, type: 'symbol' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
    ],
  },
  crop_failure: {
    svg: require('./cells/crop_failure.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/crop_failure.scss').default,
  },
  deceive: {
    svg: require('./cells/deceive.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/deceive.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  decided_to_stop_the_game: {
    svg: require('./cells/decided_to_stop_the_game.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/decided_to_stop_the_game.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'clouds_49', value: clouds_49, type: 'symbol_additional' },
      { name: 'grass', value: grass, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'cat', value: cat, type: 'symbol_additional' },
      { name: 'bird', value: bird, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  desert_island: {
    svg: require('./cells/desert_island.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/desert_island.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'bird', value: bird, type: 'symbol_additional' },
      { name: 'clouds_49', value: clouds_49, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  doomsday: {
    svg: require('./cells/doomsday.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/doomsday.scss').default,
    defs: [{ name: 'scribble', value: scribble, type: 'filter' }],
  },
  drugs_104: {
    svg: require('./cells/drugs_104.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/drugs_104.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'white_smoke', value: white_smoke, type: 'symbol_additional' },
      { name: 'drug', value: drug, type: 'symbol_additional' },
      { name: 'drug_buble', value: drug_buble, type: 'symbol_additional' },
      { name: 'blur_filter', value: blur_filter, type: 'filter' },
      { name: 'add_drugs', value: add_drugs, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  drugs_109: {
    svg: require('./cells/drugs_109.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/drugs_109.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'drug', value: drug, type: 'symbol_additional' },
      { name: 'drugsPattern', value: drugsPattern, type: 'pattern' },
      { name: 'small_coin', value: small_coin, type: 'symbol_additional' },
      { name: 'drug_buble', value: drug_buble, type: 'symbol_additional' },
      { name: 'blur_filter', value: blur_filter, type: 'filter' },
      { name: 'add_drugs', value: add_drugs, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  drugs_plantation: {
    svg: require('./cells/drugs_plantation.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/drugs_plantation.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  drunk_skip_two_times: {
    svg: require('./cells/drunk_skip_two_times.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/drunk_skip_two_times.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  dumping: {
    svg: require('./cells/dumping.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/dumping.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  ema: {
    svg: require('./cells/ema.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/ema.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  extortion: {
    svg: require('./cells/extortion.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/extortion.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  fake_coins: {
    svg: require('./cells/fake_coins.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/fake_coins.scss').default,
    defs: [
      { name: 'coin', value: coin, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'drug', value: drug, type: 'symbol_additional' },
      { name: 'drugsPattern', value: drugsPattern, type: 'pattern' },
      { name: 'drug_buble', value: drug_buble, type: 'symbol_additional' },
      { name: 'blur_filter', value: blur_filter, type: 'filter' },
      { name: 'add_drugs', value: add_drugs, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  famine_and_epidemic: {
    svg: require('./cells/famine_and_epidemic.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/famine_and_epidemic.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  farm: {
    svg: require('./cells/farm.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/farm.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  gave_godfather: {
    svg: require('./cells/gave_godfather.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/gave_godfather.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'army_defence', value: army_defence, type: 'symbol' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  godfather: {
    svg: require('./cells/godfather.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/godfather.scss').default,
  },
  gold_bucket: {
    svg: require('./cells/gold_bucket.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/gold_bucket.scss').default,
    defs: [
      { name: 'small_glare', value: small_glare, type: 'symbol_additional' },
      { name: 'glare', value: glare, type: 'symbol_additional' },
    ],
  },
  gold_mine: {
    svg: require('./cells/gold_mine.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/gold_mine.scss').default,
    defs: [
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ]
  },
  golden_tooth: {
    svg: require('./cells/golden_tooth.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/golden_tooth.scss').default,
    defs: [
      { name: 'small_glare', value: small_glare, type: 'symbol_additional' },
      { name: 'glare', value: glare, type: 'symbol_additional' },
    ],
  },
  got_into_an_accident: {
    svg: require('./cells/got_into_an_accident.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/got_into_an_accident.scss').default,
  },
  hijacking: {
    svg: require('./cells/hijacking.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/hijacking.scss').default,
  },
  hmm: {
    svg: require('./cells/hmm.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/hmm.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  insurance_10k: {
    svg: require('./cells/insurance_10k.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/insurance_10k.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  investment: {
    svg: require('./cells/investment.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/investment.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'no_taxes_defence', value: no_taxes_defence, type: 'symbol' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  investment_objective: {
    svg: require('./cells/investment_objective.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/investment_objective.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  item_amount_items48_buy: {
    svg: require('./cells/item_amount_items48_buy.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/item_amount_items48_buy.scss').default,
    defs: [
      { name: 'item_48', value: item_48, type: 'symbol_additional' },
      { name: 'elephant_pattern', value: elephant_pattern, type: 'pattern' },
    ],
  },
  item_amount_items48_sell: {
    svg: require('./cells/item_amount_items48_sell.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/item_amount_items48_sell.scss').default,
    defs: [{ name: 'item_48', value: item_48, type: 'symbol_additional' }],
  },
  justice: {
    svg: require('./cells/justice.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/justice.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  labor_cost_index_down_19: {
    svg: require('./cells/labor_cost_index_down_19.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/labor_cost_index_down_19.scss').default,
  },
  labor_cost_index_up_32: {
    svg: require('./cells/labor_cost_index_up_32.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/labor_cost_index_up_32.scss').default,
    defs: [{ name: 'flagAnimated', value: flagAnimated, type: 'animate' }],
  },
  loan: {
    svg: require('./cells/loan.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/loan.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  mmm: {
    svg: require('./cells/mmm.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/mmm.scss').default,
    defs: [
      { name: 'buble', value: buble, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  multiple_money: {
    svg: require('./cells/multiple_money.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/multiple_money.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  mutiny_on_the_ship: {
    svg: require('./cells/mutiny_on_the_ship.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/mutiny_on_the_ship.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'army_defence', value: army_defence, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
    ],
  },
  night_robbery: {
    svg: require('./cells/night_robbery.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/night_robbery.scss').default,
    defs: [
      { name: 'clouds_49', value: clouds_49, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  no_taxes: {
    svg: require('./cells/no_taxes.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/no_taxes.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'no_taxes_defence', value: no_taxes_defence, type: 'symbol' },
    ],
  },
  official_triumph: {
    svg: require('./cells/official_triumph.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/official_triumph.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  pay_tax_33_percent: {
    svg: require('./cells/pay_tax_33_percent.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/pay_tax_33_percent.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'no_taxes_defence', value: no_taxes_defence, type: 'symbol' },
      { name: 'paper', value: paper, type: 'filter' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  pearls_was_bought: {
    svg: require('./cells/pearls_was_bought.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/pearls_was_bought.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'heart', value: heart, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  perls: {
    svg: require('./cells/perls.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/perls.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  pirates: {
    svg: require('./cells/pirates.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/pirates.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'army_defence', value: army_defence, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
    ],
  },
  plantations_brought_profit: {
    svg: require('./cells/plantations_brought_profit.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/plantations_brought_profit.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  player_lock: {
    svg: require('./cells/player_lock.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/player_lock.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'envelope', value: envelope, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'bribery_of_police_defence', value: bribery_of_police_defence, type: 'symbol' },
    ],
  },
  player_lock_103: {
    svg: require('./cells/player_lock_103.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/player_lock_103.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  player_lock_105: {
    svg: require('./cells/player_lock_105.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/player_lock_105.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'envelope', value: envelope, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'bribery_of_police_defence', value: bribery_of_police_defence, type: 'symbol' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  player_lock_107: {
    svg: require('./cells/player_lock_107.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/player_lock_107.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  player_lock_92: {
    svg: require('./cells/player_lock_92.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/player_lock_92.scss').default,
    defs: [
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'bribery_of_police_defence', value: bribery_of_police_defence, type: 'symbol' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'envelope', value: envelope, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'mouse', value: mouse, type: 'symbol_additional' },
    ],
  },
  player_lock_drugs_plantation: {
    svg: require('./cells/player_lock_drugs_plantation.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/player_lock_drugs_plantation.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
    ],
  },
  population_explosion: {
    svg: require('./cells/population_explosion.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/population_explosion.scss').default,
  },
  port: {
    svg: require('./cells/port.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/port.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'rent', value: rent, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  president_tax: {
    svg: require('./cells/president_tax.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/president_tax.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'no_taxes_defence', value: no_taxes_defence, type: 'symbol' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  protess_mission: {
    svg: require('./cells/protess_mission.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/protess_mission.scss').default,
    defs: [
      { name: 'redGlow', value: redGlow, type: 'filter' },
      { name: 'blueGlow', value: blueGlow, type: 'filter' },
      { name: 'clouds_78', value: clouds_78, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  put_money_on_a_star: {
    svg: require('./cells/put_money_on_a_star.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/put_money_on_a_star.scss').default,
  },
  question_mark: {
    svg: require('./cells/question_mark.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/question_mark.scss').default,
  },
  racket: {
    svg: require('./cells/racket.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/racket.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  rebellion_in_colony: {
    svg: require('./cells/rebellion_in_colony.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/rebellion_in_colony.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'army_defence', value: army_defence, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  rent_for_pearls: {
    svg: require('./cells/rent_for_pearls.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/rent_for_pearls.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'small_glare', value: small_glare, type: 'symbol_additional' },
      { name: 'glare', value: glare, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  robbery_gold: {
    svg: require('./cells/robbery_gold.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/robbery_gold.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'army_defence', value: army_defence, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
    ],
  },
  saloon: {
    svg: require('./cells/saloon.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/saloon.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  shipwreck: {
    svg: require('./cells/shipwreck.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/shipwreck.scss').default,
    defs: [
      { name: 'fish', value: fish, type: 'symbol_additional' },
      { name: 'buble', value: buble, type: 'symbol_additional' },
      { name: 'item_48', value: item_48, type: 'symbol_additional' },
    ],
  },
  shipyards: {
    svg: require('./cells/shipyards.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/shipyards.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'bird', value: bird, type: 'symbol_additional' },
      { name: 'clouds_49', value: clouds_49, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  shooting: {
    svg: require('./cells/shooting.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/shooting.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'army_defence', value: army_defence, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'army_logo', value: army_logo, type: 'symbol_additional' },
    ],
  },
  slave_market: {
    svg: require('./cells/slave_market.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/slave_market.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'clouds_49', value: clouds_49, type: 'symbol_additional' },
    ],
  },
  sleep: {
    svg: require('./cells/sleep.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/sleep.scss').default,
  },
  steal_statue: {
    svg: require('./cells/steal_statue.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/steal_statue.scss').default,
    defs: [
      { name: 'museum', value: museum, type: 'symbol_additional' },
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  stock_exchange: {
    svg: require('./cells/stock_exchange.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/stock_exchange.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  stock_exchange_speculation_18: {
    svg: require('./cells/stock_exchange_speculation_18.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/stock_exchange_speculation_18.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
    ]
  },
  stock_exchange_speculation_24: {
    svg: require('./cells/stock_exchange_speculation_24.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/stock_exchange_speculation_24.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
    ]
  },
  stock_exchange_speculation_81: {
    svg: require('./cells/stock_exchange_speculation_81.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/stock_exchange_speculation_81.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'flagAnimated', value: flagAnimated, type: 'animate' },
      { name: 'clouds_29', value: clouds_29, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
    ],
  },
  street_29: {
    svg: require('./cells/street_29.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/street_29.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'rent', value: rent, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'clouds_29', value: clouds_29, type: 'symbol_additional' },
      { name: 'cat', value: cat, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  street_49: {
    svg: require('./cells/street_49.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/street_49.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'rent', value: rent, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'clouds_49', value: clouds_49, type: 'symbol_additional' },
      { name: 'cat', value: cat, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  street_63: {
    svg: require('./cells/street_63.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/street_63.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'rent', value: rent, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'clouds_63', value: clouds_63, type: 'symbol_additional' },
      { name: 'cat', value: cat, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  street_78: {
    svg: require('./cells/street_78.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/street_78.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'rent', value: rent, type: 'symbol' },
      { name: 'hand_with_coin', value: hand_with_coin, type: 'symbol_additional' },
      { name: 'clouds_78', value: clouds_78, type: 'symbol_additional' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  strike: {
    svg: require('./cells/strike.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/strike.scss').default,
  },
  swimming_in_the_coca_cola: {
    svg: require('./cells/swimming_in_the_coca_cola.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/swimming_in_the_coca_cola.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buble', value: buble, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  take_away_money_in: {
    svg: require('./cells/take_away_money_in.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/take_away_money_in.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
    ],
  },
  take_from_budget: {
    svg: require('./cells/take_from_budget.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/take_from_budget.scss').default,
    defs: [{ name: 'small_glare', value: small_glare, type: 'symbol_additional' }],
  },
  tax_on_plantations: {
    svg: require('./cells/tax_on_plantations.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/tax_on_plantations.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'no_taxes_defence', value: no_taxes_defence, type: 'symbol' },
      { name: 'bird', value: bird, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
  terrorist: {
    svg: require('./cells/terrorist.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/terrorist.scss').default,
  },
  three_kg_gold_treasure_found: {
    svg: require('./cells/three_kg_gold_treasure_found.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/three_kg_gold_treasure_found.scss').default,
    defs: [{ name: 'small_glare', value: small_glare, type: 'symbol_additional' }],
  },
  travel_agency: {
    svg: require('./cells/travel_agency.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/travel_agency.scss').default,
  },
  triple_step: {
    svg: require('./cells/triple_step.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/triple_step.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'triple_step', value: triple_step, type: 'symbol' },
      { name: 'grass', value: grass, type: 'symbol_additional' },
    ],
  },
  war_factory: {
    svg: require('./cells/war_factory.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/war_factory.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'buy', value: buy, type: 'symbol' },
      { name: 'sell', value: sell, type: 'symbol' },
      { name: 'star', value: star, type: 'symbol_additional' },
      { name: 'confetti', value: confetti, type: 'symbol_additional' },
      { name: 'add_star', value: add_star, type: 'symbol' },
    ],
  },
  will_not_bring_profit: {
    svg: require('./cells/will_not_bring_profit.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/will_not_bring_profit.scss').default,
  },
  lottery: {
    svg: require('./cells/lottery.svg'),
    css: require('!!css-loader!sass-loader!../scss/cells/lottery.scss').default,
    defs: [
      { name: 'black_background', value: black_background, type: 'symbol_additional' },
      { name: 'player_lock', value: player_lock, type: 'symbol' },
      { name: 'boom', value: boom, type: 'symbol_additional' },
      { name: 'gold_up', value: '', type: 'symbol' },
      { name: 'gold', value: '', type: 'symbol' },
      { name: 'triple_step', value: triple_step, type: 'symbol' },
      { name: 'winner', value: winner, type: 'symbol' },
      { name: 'lost', value: lost, type: 'symbol' },
      { name: 'add_money', value: add_money, type: 'symbol' },
      { name: 'dollar', value: dollar, type: 'symbol_additional' },
      { name: 'wing', value: wing, type: 'symbol_additional' },
      { name: 'money_with_wings', value: money_with_wings, type: 'symbol_additional' },
      { name: 'remove_money', value: remove_money, type: 'symbol' },
    ],
  },
};
